@@ -139,6 +139,8 @@ Built-in roles are:
   prosody:admin      - Host administrator
   prosody:operator   - Server administrator
 
+To view roles and policies, see the commands in 'help role'.
+
 Roles can be assigned using the user management commands (see 'help user').
 ]];
 
@@ -1585,7 +1587,7 @@ function def_env.s2s:close(from, to, text, condition)
 
 	for _, session in pairs(s2s_sessions) do
 		local id = session.id or (session.type .. tostring(session):match("[a-f0-9]+$"));
-		if (match_id and match_id == id) or ((from and match_wildcard(from, session.to_host)) or (to and match_wildcard(to, session.to_host))) then
+		if (match_id and match_id == id) or ((from and match_wildcard(from, session.from_host)) and (to and match_wildcard(to, session.to_host))) then
 			print(("Closing connection from %s to %s [%s]"):format(session.from_host, session.to_host, id));
 			(session.close or s2smanager.destroy_session)(session, build_reason(text, condition));
 			count = count + 1;
@@ -2049,22 +2051,22 @@ end
 
 def_env.xmpp = new_section("Commands for sending XMPP stanzas");
 
-describe_command [[xmpp:ping(localhost, remotehost) - Sends a ping to a remote XMPP server and reports the response]]
+describe_command [[xmpp:ping(localjid, remotejid) - Sends a ping to an XMPP entity and reports the response]]
 local new_id = require "prosody.util.id".medium;
-function def_env.xmpp:ping(localhost, remotehost, timeout)
-	localhost = select(2, jid_split(localhost));
-	remotehost = select(2, jid_split(remotehost));
+function def_env.xmpp:ping(localjid, remotejid, timeout)
+	local localnode, localhost, localresource = jid_split(localjid);
+	local remotenode, remotehost, remoteresource = jid_split(remotejid);
 	if not localhost then
-		return nil, "Invalid sender hostname";
+		return nil, "Invalid sender JID";
 	elseif not prosody.hosts[localhost] then
 		return nil, "No such local host";
+	elseif localresource then
+		return nil, "Server can't send ping from local resource"; -- Would require creating a temporary session with bound resource and everything
 	end
 	if not remotehost then
-		return nil, "Invalid destination hostname";
-	elseif prosody.hosts[remotehost] then
-		return nil, "Both hosts are local";
+		return nil, "Invalid destination JID";
 	end
-	local iq = st.iq{ from=localhost, to=remotehost, type="get", id=new_id()}
+	local iq = st.iq { from = jid_join(localnode, localhost); to = jid_join(remotenode, remotehost, remoteresource); type = "get"; id = new_id() }
 			:tag("ping", {xmlns="urn:xmpp:ping"});
 	local time_start = time.now();
 	local print = self.session.print;
@@ -2081,6 +2083,12 @@ function def_env.xmpp:ping(localhost, remotehost, timeout)
 			end
 		end
 	end
+	if localhost == remotehost or prosody.hosts[remotehost] then
+		-- No s2s connections will be triggered
+		return module:context(localhost):send_iq(iq, nil, timeout):next(function(pong)
+			return ("pong from %s in %gs"):format(pong.stanza.attr.from, time.now() - time_start);
+		end);
+	end
 	local onconnected = onchange("connected");
 	local onauthenticated = onchange("authenticated");
 	local onestablished = onchange("established");
@@ -2458,6 +2466,64 @@ function def_env.debug:cert_index(path)
 	return true, ("Showing %d certificates in %s"):format(c, path);
 end
 
+def_env.role = new_section("Role and access management");
+
+describe_command [[role:list(host) - List known roles]]
+function def_env.role:list(host)
+	if not host then
+		return nil, "Specify which host to list roles for";
+	end
+	local role_list = {};
+	for _, role in it.sorted_pairs(um.get_all_roles(host)) do
+		table.insert(role_list, role);
+	end
+	table.sort(role_list, function (a, b)
+		if a.priority ~= b.priority then
+			return (a.priority or 0) > (b.priority or 0);
+		end
+		return a.name < b.name;
+	end);
+	for _, role in ipairs(role_list) do
+		self.session.print(role.name);
+	end
+	return true, ("Showing %d roles on %s"):format(#role_list, host);
+end
+
+describe_command [[role:show(host, role_name) - Show information about a role]]
+function def_env.role:show(host, role_name)
+	if not host or not role_name then
+		return nil, "Specify the host and role to show";
+	end
+
+	local print = self.session.print;
+	local role = um.get_role_by_name(role_name, host);
+
+	if not role then
+		return nil, ("Unable to find role %s on host %s"):format(role_name, host);
+	end
+
+	local inherits = {};
+	for _, inherited_role in ipairs(role.inherits or {}) do
+		table.insert(inherits, inherited_role.name);
+	end
+
+	local permissions = {};
+	for permission, is_allowed in role:policies() do
+		permissions[permission] = is_allowed and "allowed" or "denied";
+	end
+
+	print("Name:    ", role.name);
+	print("Inherits:", table.concat(inherits, ", "));
+	print("Policies:");
+	local c = 0;
+	for permission, policy in it.sorted_pairs(permissions) do
+		c = c + 1;
+		print("  ["..(policy == "allowed" and "+" or " ").."] " .. permission);
+	end
+	print("");
+	return true, ("Showing role %s with %d policies"):format(role.name, c);
+end
+
 def_env.stats = new_section("Commands to show internal statistics");
 
 local short_units = {
